spoon

Package spoon |
[hide private]
[frames] | no frames]

# Source Code for Package spoon

     1  #
     2  # Copyright (C) 2006, Matt Sullivan <matts@zarrf.com>
     3  #
     4  # Permission is hereby granted, free of charge, to any person obtaining
     5  # a copy of this software and associated documentation files (the
     6  # "Software"), to deal in the Software without restriction, including
     7  # without limitation the rights to use, copy, modify, merge, publish,
     8  # distribute, sublicense, and/or sell copies of the Software, and to
     9  # permit persons to whom the Software is furnished to do so, subject to
    10  # the following conditions:
    11  #
    12  # The above copyright notice and this permission notice shall be included
    13  # in all copies or substantial portions of the Software.
    14  #
    15  # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    16  # OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    17  # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    18  # IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
    19  # CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
    20  # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    21  # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
    22  #
    23
    24  __author__ = "Matt Sullivan <matts@zarrf.com>"
    25  __date__ = "22 Nov 2006"
    26  __version__ = "0.1.1"
    27  __version_info__ = (0,1,1)
    28  __license__ = "MIT/X Consortium"
    29
    30
    31  from spooncore import Serial, serialprop, lazyprop
    32  from spooncore import SPOONLINKMSG_TAG as __SPOONLINKMSG_TAG__, SPOONNETMSG_TAG as __SPOONNETMSG_TAG__
    33  from spoonstream import SpoonStream
    34  from nulllogger import NullLogger
    35  from objTypes import *
    36
    37  for x in [Serial, serialprop, lazyprop, SpoonStream, NullLogger]:
    38      x.__module__ = "spoon"
    39
    40  import messaging
    41  import routing
    42  import transports
    43  import ber
    44
    45  messaging.__module__ = "spoon"
    46  routing.__module__ = "spoon"
    47  transports.__module__ = "spoon"
    48  ber.__module__ = "spoon"
    49
    50  __all__ = ["Serial",
    51             "serialprop",
    52             "lazyprop",
    53             "SpoonStream",
    54             "NullLogger",
    55             "messaging",
    56             "routing",
    57             "transports",
    58             "ber"]
    59